package com.datacloudsec.scan.service.impl;

import com.datacloudsec.bline.engine.db.Engine;
import com.datacloudsec.bline.engine.db.entity.Policie;
import com.datacloudsec.bline.engine.db.handler.IHandler;
import com.datacloudsec.engine.db.auth.AbsDb;
import com.datacloudsec.engine.db.handler.DbHandler;
import com.datacloudsec.engine.db.handler.IVirusHandler;
import com.datacloudsec.engine.db.noauth.NoAuthDb;
import com.datacloudsec.engine.db.noauth.NoAuthEngine;
import com.datacloudsec.engine.db.nosql.AbsNoSqlDb;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Config;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.BlineBugMapper;
import com.datacloudsec.scan.dao.BlineevalMapper;
import com.datacloudsec.scan.dao.ConfigMapper;
import com.datacloudsec.scan.dao.DBBugMapper;
import com.datacloudsec.scan.dao.DbTempMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.HostMapper;
import com.datacloudsec.scan.dao.TaskBaseMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IHost;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.SysLogJob;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.KafkaUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.ConnectException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.nio.charset.Charset;
import java.security.SecureRandom;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/EngineService.class */
public class EngineService implements IEngine {
    private static final int TIMEOUT = 300000;
    private static final int UPGRADE_TIMEOUT = 600000;
    private static final String SIGN_KEY = "Token";
    private static final int WEB_MAXSCAN = 10;
    private static final int AVAIL_MAXSCAN = 64;
    private static final int SYS_MAXSCAN = 10;
    private static final int BLINE_MAXSCAN = 10;
    private static final int PWD_MAXSCAN = 10;
    public static final String post = "POST";
    public static final String get = "GET";
    private static final Logger LOG = Logger.getLogger(EngineService.class);
    private static final byte[] ENGINE_PASSWORD = Config.getInstance().getString("engine-password", "").getBytes();
    private static HostMapper hostMapper = (HostMapper) InstanceUtil.newDaoInstance(HostMapper.class);
    private static EngineMapper engMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);
    private static BlineBugMapper blineBugMapper = (BlineBugMapper) InstanceUtil.newDaoInstance(BlineBugMapper.class);
    private static DBBugMapper dbBugMapper = (DBBugMapper) InstanceUtil.newDaoInstance(DBBugMapper.class);
    private static TaskBaseMapper taskBaseMapper = (TaskBaseMapper) InstanceUtil.newDaoInstance(TaskBaseMapper.class);
    private static IReport reportService = (IReport) InstanceUtil.newServiceInstance(ReportService.class);
    private static AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);
    private static DbTempMapper dbTempMapper = (DbTempMapper) InstanceUtil.newDaoInstance(DbTempMapper.class);
    private static BlineevalMapper blineevalMapper = (BlineevalMapper) InstanceUtil.newDaoInstance(BlineevalMapper.class);
    private static ConfigMapper configMapper = (ConfigMapper) InstanceUtil.newDaoInstance(ConfigMapper.class);

    public IEngine.EngineResult webScan(String url, String method, String referer, String body, Map<String, String> taskOption) throws Exception {
        Map<String, String> lic = InitSystemTask.licenseApp.getLicenseLic().getParams();
        Integer maxScan = 10;
        for (String key : ObjectUtil.getString(lic.get("cmp"), "").split("/")) {
            String[] keyS = key.split(":");
            if (keyS.length > 3 && "webscan".equals(keyS[0])) {
                Integer maxTemp = Integer.valueOf(ObjectUtil.getInt(keyS[3], 10));
                maxScan = Integer.valueOf(maxTemp.intValue() == 0 ? 10 : maxTemp.intValue());
            }
        }
        Map<String, Object> engineInfo = hostMapper.getAddressForTask(3, 0, maxScan);
        if (engineInfo == null || engineInfo.size() == 0) {
            return null;
        }
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "SCANTASK");
        params.put("taskOption", taskOption);
        Map<String, Object> info = new HashMap<>();
        info.put("url", url);
        info.put("method", method);
        info.put("referer", referer);
        info.put("body", body);
        params.put("site", info);
        String engineId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 1), engineId);
    }

    public IEngine.EngineResult availScan(String url, String method, String referer, String body, Map<String, String> taskOption) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAvailAddrForTask(Integer.valueOf(AVAIL_MAXSCAN));
        if (engineInfo == null || engineInfo.size() == 0) {
            return null;
        }
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "SCANTASK");
        params.put("taskOption", taskOption);
        Map<String, Object> info = new HashMap<>();
        info.put("url", url);
        info.put("method", method);
        info.put("referer", referer);
        info.put("body", body);
        params.put("site", info);
        String engineId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 1), engineId);
    }

    public boolean webDelete(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "DELETETASK");
        params.put("TaskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public void webRestore(String ip, int port) throws Exception {
        invokeGet(ip, port, "/v1/close", false, new String[0]);
    }

    public boolean webRescan(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "RESTARTTASK");
        params.put("TaskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public boolean webContinuescan(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "RESUMETASK");
        params.put("TaskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public boolean webStop(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "STOPTASK");
        params.put("TaskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public Map<String, Object> webGetResult(String engineId, int localEid, int urlOffset, int urlLimit, int siteOffset, int siteLimit, int issuesOffset, int issuesLimit) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        return invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/results/" + engineId + "/urls/" + urlOffset + "/" + urlLimit + "/sites/" + siteOffset + "/" + siteLimit + "/issues/" + issuesOffset + "/" + issuesLimit, false, "result");
    }

    public List<Map<String, Object>> webEngines(int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        return (List) invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/engines/", false, "engines").get("engines");
    }

    public Map<String, Object> insertWebPolicy(Map<String, Object> options) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(3);
        return invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/policy", false, options, new String[0]);
    }

    public void delWebPolicy(String policyid) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(3);
        invokeDelete(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/policy/" + policyid, false, new String[0]);
    }

    public Map<String, Object> startWebProxy(String url, Integer port, Integer deviceid, String reqUrl) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(3);
        Map<String, Object> options = new HashMap<>();
        options.put("url", url);
        options.put("port", port);
        options.put("deviceid", new StringBuilder().append(deviceid).toString());
        options.put("reqUrl", reqUrl);
        return invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/proxy", false, options, new String[0]);
    }

    public void stopWebProxy(Integer pid) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(3);
        invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/proxy/" + pid, false, new String[0]);
    }

    public Map<String, Object> peneTest(Map<String, Object> options) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(3);
        return invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/pene", false, options, new String[0]);
    }

    public IEngine.EngineResult sysScan(String ip, Map<String, String> taskOption) throws Exception {
        Map<String, String> lic = InitSystemTask.licenseApp.getLicenseLic().getParams();
        Integer maxScan = 10;
        for (String key : ObjectUtil.getString(lic.get("cmp"), "").split("/")) {
            String[] keyS = key.split(":");
            if (keyS.length > 3 && "sysscan".equals(keyS[0])) {
                Integer maxTemp = Integer.valueOf(ObjectUtil.getInt(keyS[3], 10));
                maxScan = Integer.valueOf(maxTemp.intValue() == 0 ? 10 : maxTemp.intValue());
            }
        }
        Map<String, Object> engineInfo = hostMapper.getAddressForSysTask(5, 1, maxScan);
        if (engineInfo == null || engineInfo.size() == 0) {
            return null;
        }
        Map<String, Object> params = new HashMap<>();
        params.put("type", "sysscan");
        params.put("operate", "SCANTASK");
        params.put("hosts", ip);
        params.put("taskOption", taskOption);
        String engineId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 5), engineId);
    }

    public boolean sysDelete(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "DELETETASK");
        params.put("taskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public void sysRestore(String ip, int port) throws Exception {
        invokeGet(ip, port, "/v1/close", false, new String[0]);
    }

    public boolean sysStop(String id, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "STOPTASK");
        params.put("taskID", id);
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public Map<String, Object> sysGetResult(String engineId, int localEid, int vulsOffset, int vulsLimit, int errsOffset, int errsLimit) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        return invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/results/" + engineId + "/vuls/" + vulsOffset + "/" + vulsLimit + "/errs/" + errsOffset + "/" + errsLimit + "/pwds/0/0", false, "result");
    }

    public String getMachineCode() throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(5);
        return ObjectUtil.getString(invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/getmachinecode", false, "result").get("result"), "");
    }

    public String getLicTime() throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(5);
        return ObjectUtil.getString(invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/getlictime", false, "result").get("result"), "");
    }

    public void dbScan(int deviceId, String ip, Map<String, String> taskOption) throws Exception {
        String checkauth = ObjectUtil.getString(taskOption.get("checkauth"), "");
        if ("nosql".equalsIgnoreCase(checkauth)) {
            nosqlDbScan(deviceId, ip, taskOption);
            return;
        }
        String username = ObjectUtil.getString(taskOption.get("username"), (String) null);
        if (StringUtils.isNotBlank(username)) {
            authDbScan(deviceId, ip, taskOption);
        } else {
            noauthDbScan(deviceId, ip, taskOption);
        }
    }

    public boolean testDBConnection(String type, String ip, int port, String username, String password, String dbname, Integer connectType, String checkauth, int role, boolean useSsl) throws Exception {
        if ("nosql".equals(checkauth)) {
            AbsNoSqlDb db = AbsNoSqlDb.createDb(type, ip, port, username, password);
            return db.testConnection();
        }
        AbsDb db2 = AbsDb.createDb(type, ip, port, username, password, dbname, connectType.intValue(), role, useSsl);
        return db2.testConnection();
    }

    public IEngine.EngineResult pwdScan(String ip, Map<String, String> taskOption, List<Map<String, String>> brute) throws Exception {
        Map<String, String> lic = InitSystemTask.licenseApp.getLicenseLic().getParams();
        Integer maxScan = 10;
        for (String key : ObjectUtil.getString(lic.get("cmp"), "").split("/")) {
            String[] keyS = key.split(":");
            if (keyS.length > 3 && "pwd".equals(keyS[0])) {
                Integer maxTemp = Integer.valueOf(ObjectUtil.getInt(keyS[3], 10));
                maxScan = Integer.valueOf(maxTemp.intValue() == 0 ? 10 : maxTemp.intValue());
            }
        }
        Map<String, Object> engineInfo = hostMapper.getAddressForTask(4, 2, maxScan);
        if (engineInfo == null || engineInfo.size() == 0) {
            return null;
        }
        Map<String, Object> params = new HashMap<>();
        params.put("type", "brute");
        params.put("operate", "SCANTASK");
        params.put("hosts", ip);
        params.put("taskOption", taskOption);
        params.put("bruteOption", brute);
        String engineId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 4), engineId);
    }

    public boolean pwdDelete(String id, int localEid) throws Exception {
        return sysDelete(id, localEid);
    }

    public void pwdRestore(String ip, int port) throws Exception {
        sysRestore(ip, port);
    }

    public boolean pwdStop(String id, int localEid) throws Exception {
        return sysStop(id, localEid);
    }

    public Map<String, Object> pwdGetResult(String engineId, int localEid, int offset, int limit) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        return (Map) invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/results/" + engineId + "/vuls/0/0/errs/0/0/pwds/" + offset + "/" + limit, false, "result").get("result");
    }

    public IEngine.EngineResult blineScan(int deviceId, String ip, Map<String, String> taskOption) throws Exception {
        Map<String, String> lic = InitSystemTask.licenseApp.getLicenseLic().getParams();
        Integer maxScan = 10;
        for (String key : ObjectUtil.getString(lic.get("cmp"), "").split("/")) {
            String[] keyS = key.split(":");
            if (keyS.length > 3 && "bline".equals(keyS[0])) {
                Integer maxTemp = Integer.valueOf(ObjectUtil.getInt(keyS[3], 10));
                maxScan = Integer.valueOf(maxTemp.intValue() == 0 ? 10 : maxTemp.intValue());
            }
        }
        Map<String, Object> engineInfo = hostMapper.getAddressForTask(6, 2, maxScan);
        if (engineInfo == null || engineInfo.size() == 0) {
            return null;
        }
        Map<String, Object> params = new HashMap<>();
        params.put("operate", "SCANTASK");
        params.put("taskOption", taskOption);
        String engineId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 6), engineId);
    }

    /* JADX WARN: Type inference failed for: r0v46, types: [com.datacloudsec.scan.service.impl.EngineService$1] */
    public void blineDbScan(final int deviceId, String ip, Map<String, String> taskOption, final Integer scanCount) throws Exception {
        String username = taskOption.get("username");
        String password = taskOption.get("password");
        String dbname = taskOption.get("dbname");
        final String dbT = ObjectUtil.getString(taskOption.get("db"), "000");
        int port = ObjectUtil.getInt(taskOption.get("port"), 3306);
        int connectType = ObjectUtil.getInt(taskOption.get("connect_type"), 1);
        int role = ObjectUtil.getInt(taskOption.get("role"), 0);
        boolean useSsl = ObjectUtil.getBoolean(taskOption.get("useSsl"));
        final Map<String, String> policie = new HashMap<>();
        policie.put("001", "oracle.xml");
        policie.put("002", "mysql.xml");
        policie.put("003", "sqlserver.xml");
        policie.put("004", "postgresql.xml");
        policie.put("005", "db2.xml");
        policie.put("006", "sybase.xml");
        policie.put("007", "informix.xml");
        policie.put("008", "dm.xml");
        policie.put("009", "kingbase.xml");
        final com.datacloudsec.bline.engine.db.connect.AbsDb db = com.datacloudsec.bline.engine.db.connect.AbsDb.createDb(dbT, ip, port, username, password, dbname, connectType, role, useSsl);
        new Thread() { // from class: com.datacloudsec.scan.service.impl.EngineService.1
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                new Engine().scan(db, new DbBlineHandler(deviceId, scanCount.intValue()), (Map) null, new File(Constant.WORK_DIR, "conf/blinepolicie/default/" + ((String) policie.get(dbT))));
            }
        }.start();
    }

    public boolean blineDelete(int devType, String id, int localEid) throws Exception {
        if (devType != 8) {
            Map<String, Object> engineInfo = getHostById(localEid);
            Map<String, Object> params = new HashMap<>();
            params.put("operate", "DELETETASK");
            params.put("taskID", id);
            invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
            return true;
        }
        return true;
    }

    public void blineRestore(String ip, int port) throws Exception {
        invokeGet(ip, port, "/v1/close", false, new String[0]);
    }

    public Map<String, Object> blineGetResult(int devType, String engineId, int localEid, int offset, int limit, int errsOffset, int errsLimit) throws Exception {
        if (devType == 8) {
            return null;
        }
        Map<String, Object> engineInfo = getHostById(localEid);
        return invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/" + engineId + "/results/" + offset + "/" + limit + "/errs/" + errsOffset + "/" + errsLimit, false, new String[0]);
    }

    public Map<String, Object> addBlinePolicy(Map<String, Object> options) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(6);
        return invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/policy", false, options, new String[0]);
    }

    public Map<String, Object> updBlinePolicy(Map<String, Object> options, String policyid) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(6);
        return invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/policy/update/" + policyid, false, options, new String[0]);
    }

    public void delBlinePolicy(String policyid) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(6);
        invokeDelete(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/policy/" + policyid, false, new String[0]);
    }

    public Map<String, Object> wifiScan() throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            return invokeGet(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/change/start", false, new String[0]);
        }
        return null;
    }

    public Map<String, Object> wifiStop() throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            return invokeGet(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/change/stop", false, new String[0]);
        }
        return null;
    }

    public Map<String, Object> wifiIsSearch() throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            return invokeGet(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/change/search", false, new String[0]);
        }
        return null;
    }

    public Map<String, Object> wifiGetResult() throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            return invokeGet(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/get", false, new String[0]);
        }
        return null;
    }

    public Map<String, Object> wifiWeakPwd(String mac, String password) throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            Map<String, Object> params = new HashMap<>();
            params.put("mac", mac);
            params.put("method", "start");
            if (StringUtils.isNotBlank(password)) {
                params.put("password", password);
            }
            return invokePost(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/crack", false, params, new String[0]);
        }
        return null;
    }

    public Map<String, Object> wifiGetWeakPwd(String mac) throws Exception {
        List<Map<String, Object>> wifiEngs = engMapper.getEngineByType(11);
        if (wifiEngs != null && wifiEngs.size() > 0) {
            Map<String, Object> wifiEng = wifiEngs.get(0);
            Map<String, Object> params = new HashMap<>();
            params.put("mac", mac);
            params.put("method", "get");
            return invokePost(ObjectUtil.getString(wifiEng.get("ip"), ""), ObjectUtil.getInt(wifiEng.get("port"), ((Integer) IHost.TYPE_PORT.get(11)).intValue()), "/v1/wifi/crack", false, params, new String[0]);
        }
        return null;
    }

    public void sniffingRestore(String ip, int port) throws Exception {
        invokeGet(ip, port, "/v1/close", false, new String[0]);
    }

    public IEngine.EngineResult sniffingStart(String ip, String port, String pingonly, String servciescan, String portscan, String zombiehost) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getAddress(1);
        if (engineInfo == null) {
            throw new UEException("未找到对应的引擎");
        }
        Map<String, Object> params = new HashMap<>();
        params.put("hosts", ip);
        params.put("operate", "SCANTASK");
        params.put("pingonly", pingonly);
        Map<String, Object> info = new HashMap<>();
        info.put("tcp_range", port);
        info.put("pingonly", pingonly);
        info.put("servciescan", servciescan);
        if (StringUtils.isNotBlank(portscan)) {
            info.put("portscan", portscan);
        }
        if (StringUtils.isNotBlank(zombiehost)) {
            info.put("zombiehost", zombiehost);
        }
        params.put("taskOption", info);
        String taskId = (String) invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, "TaskID").get("TaskID");
        return new IEngine.EngineResult(ObjectUtil.getInt(engineInfo.get("id"), 0), taskId);
    }

    public Map<String, Object> sniffingResult(String eid, int localEid, int offset, int limit) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        return (Map) invokeGet(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/results/" + eid + "/hosts/" + offset + "/" + limit, false, "result").get("result");
    }

    public boolean sniffingStop(String eid, int localEid) throws Exception {
        Map<String, Object> engineInfo = getHostById(localEid);
        Map<String, Object> params = new HashMap<>();
        params.put("TaskID", eid);
        params.put("operate", "STOPTASK");
        invokePost(ObjectUtil.getString(engineInfo.get("ip"), ""), ObjectUtil.getInt(engineInfo.get("port"), 0), "/v1/task", false, params, new String[0]);
        return true;
    }

    public boolean hostOper(Integer id, boolean isReboot) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        return hostOper(ObjectUtil.getString(hostInfo.get("ip"), ""), isReboot);
    }

    public boolean hostOper(String ip, boolean isReboot) throws Exception {
        invokeGet(ip, 9999, "/v1/machine?method=" + (isReboot ? "reboot" : "shutdown"), true, new String[0]);
        return true;
    }

    public Map<String, Object> getNetcard(Integer id) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        return invokeGet(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/netmanager/get", false, new String[0]);
    }

    public Map<String, Object> getRoute(Integer id) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> params = new HashMap<>();
        params.put("method", "get");
        return invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/route", false, params, new String[0]);
    }

    public boolean route(Integer id, String method, List<Map<String, Object>> route) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> params = new HashMap<>();
        params.put("method", method);
        params.put("route", route);
        invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/route", false, params, new String[0]);
        return true;
    }

    public Map<String, Object> getRule(Integer id) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> params = new HashMap<>();
        params.put("method", "get");
        return invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/rule", false, params, new String[0]);
    }

    public boolean addRule(Integer id, String from, String to, String iif, String oif, String pref, Integer table, List<Map<String, Object>> route) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> rule = new HashMap<>();
        rule.put("from", from);
        rule.put("to", to);
        rule.put("iif", iif);
        rule.put("oif", oif);
        rule.put("pref", pref);
        rule.put("route", route);
        Map<String, Object> params = new HashMap<>();
        params.put("method", "add");
        params.put("rule", rule);
        System.out.println(JsonUtil.MAPPER.writeValueAsString(params));
        invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/rule", false, params, new String[0]);
        return true;
    }

    public boolean delRule(Integer id, String from, Integer table) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> rule = new HashMap<>();
        rule.put("from", from);
        rule.put("table", table);
        Map<String, Object> params = new HashMap<>();
        params.put("method", "delete");
        params.put("rule", rule);
        invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/rule", false, params, new String[0]);
        return true;
    }

    public Map<String, Object> getHostInfo(String ip) throws Exception {
        return invokeGet(ip, 9999, "/v1/server/get", false, new String[0]);
    }

    public boolean conupNetcard(Integer id, boolean status, String name, String nictype) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        invokeGet(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/netmanager/status?nictype=" + nictype + "&method=" + (status ? "up" : "down") + "&name=" + name, false, new String[0]);
        return true;
    }

    public boolean updateNetcard(Integer id, String conname, String name, String ip, String method, String gateway, String dns1, String dns2, String operateType, boolean isdefault, String ipv6, String methodv6, String dnsv6, String gatewayv6) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        Map<String, Object> params = new HashMap<>();
        params.put("method", operateType);
        Map<String, Object> nic_con = new HashMap<>();
        nic_con.put("name", conname);
        nic_con.put("dev_name", name);
        nic_con.put("method", StringUtils.isBlank(method) ? "manual" : method);
        nic_con.put("type", "ethernet");
        nic_con.put("gateway", gateway);
        nic_con.put("isdefault", Boolean.valueOf(isdefault));
        if (StringUtils.isNotBlank(ipv6)) {
            nic_con.put("ipv6", StringUtils.isBlank(ipv6) ? new String[]{ipv6} : ipv6.split(","));
            nic_con.put("dnsv6", StringUtils.isBlank(dnsv6) ? new String[]{dnsv6} : dnsv6.split(","));
            nic_con.put("gatewayv6", gatewayv6);
            nic_con.put("methodv6", "manual");
        } else if (StringUtils.isNotBlank(methodv6) && "auto".equals(methodv6)) {
            nic_con.put("methodv6", "auto");
        }
        if (StringUtils.isNotBlank(ip)) {
            nic_con.put("ip", StringUtils.isBlank(ip) ? new String[]{""} : ip.split(","));
            nic_con.put("dns", new String[]{dns1, dns2});
        }
        params.put("nic_con", nic_con);
        invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/netmanager/set", false, params, new String[0]);
        return true;
    }

    public boolean delNetcard(Integer id, String name) throws Exception {
        Map<String, Object> hostInfo = getHostById(id.intValue());
        invokeGet(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/netmanager/condel?name=" + name, false, new String[0]);
        return true;
    }

    public List<Map<String, Object>> sendUpgrade(Integer type, File f) throws Exception {
        List<Map<String, Object>> results = new ArrayList<>();
        if (type.intValue() == 999) {
            List<String> ips = hostMapper.getEngGroupByIp();
            for (String ip : ips) {
                Map<String, Object> params = new HashMap<>();
                params.put("etype", IHost.PRODUCT_TYPE.get(type));
                Map<String, Object> result = invokePostFile(ip, 9999, "/v1/server/upgradeall", false, params, f, new String[0]);
                result.put("etype", IHost.PRODUCT_TYPE.get(type));
                result.put("ip", ip);
                results.add(result);
            }
        } else {
            List<Map<String, Object>> hostInfos = engMapper.getEngineByType(type);
            for (Map<String, Object> hostInfo : hostInfos) {
                Map<String, Object> params2 = new HashMap<>();
                params2.put("etype", IHost.PRODUCT_TYPE.get(type));
                Map<String, Object> result2 = invokePostFile(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/server/upgradeall", false, params2, f, new String[0]);
                result2.put("etype", IHost.PRODUCT_TYPE.get(type));
                result2.put("ip", ObjectUtil.getString(hostInfo.get("ip"), ""));
                results.add(result2);
            }
        }
        f.delete();
        return results;
    }

    public List<Map<String, Object>> getEngineByType(Integer type) {
        return engMapper.getEngineByType(type);
    }

    public List<Map<String, Object>> getEngTypeVer() throws Exception {
        return engMapper.getEngTypeVer();
    }

    public Integer getEngCountByType(Integer type) throws Exception {
        return engMapper.getEngCountByType(type);
    }

    public boolean testConnection(String ip, String username, String password, String superpwd, Integer port, String protocol, String share, String domain) throws Exception {
        Map<String, Object> hostInfo = hostMapper.getLowLoadHost();
        if (hostInfo == null) {
            throw new UEException("扫描引擎不在线！");
        }
        Map<String, Object> params = new HashMap<>();
        params.put("ip", ip);
        params.put("uname", username);
        params.put("password", password);
        params.put("superpwd", superpwd);
        params.put("port", ObjectUtil.getString(port, (String) null));
        params.put("protocol", protocol);
        params.put("share", share);
        params.put("domain", domain);
        try {
            invokePost(ObjectUtil.getString(hostInfo.get("ip"), ""), 9999, "/v1/connect", false, params, new String[0]);
            return true;
        } catch (Exception e) {
            LOG.error("连接错误：", e);
            if (e != null && e.getMessage().contains("错误信息")) {
                throw e;
            }
            Process process = null;
            try {
                process = Runtime.getRuntime().exec(new String[]{"/bin/sh", "-c", "sudo systemctl restart daemonservice"});
                if (process.waitFor() != 0) {
                    String error = IOUtils.toString(process.getErrorStream(), Charset.defaultCharset().toString());
                    LOG.error(error);
                    throw new UEException("连接失败！");
                }
                String err = IOUtils.toString(process.getErrorStream(), Charset.defaultCharset().toString());
                if (StringUtils.isNotBlank(err)) {
                    LOG.error(err);
                    throw new UEException("连接失败！");
                }
                throw new UEException("连接失败，正在恢复，请稍后重试...");
            } finally {
                if (process != null) {
                    try {
                        process.destroy();
                    } catch (Exception e2) {
                    }
                }
            }
        }
    }

    public Map<String, Object> createScantool(String ip, Integer port, String type, String[] urls, Integer taskid) throws Exception {
        if (urls == null || urls.length == 0) {
            throw new UEException("扫描失败，未发现需要扫描的网站地址！");
        }
        Map<String, Object> params = new HashMap<>();
        params.put("taskid", new StringBuilder().append(taskid).toString());
        params.put("type", type);
        params.put("urls", urls);
        return invokeHttpPost(ip, port.intValue(), "/scan", false, params, new String[0]);
    }

    public Map<String, Object> quitScantool(String ip, Integer port) throws Exception {
        Map<String, Object> result = null;
        try {
            result = invokeHttpGet(ip, port.intValue(), "/exit", false, new String[0]);
        } catch (Exception e) {
            if (!e.getMessage().contains("引擎连接被断开")) {
                throw e;
            }
        }
        return result;
    }

    public File downLoadFile(String urlStr, String fileName, String savePath) throws Exception {
        HttpURLConnection conn = (HttpURLConnection) new URL(urlStr).openConnection();
        conn.setConnectTimeout(UPGRADE_TIMEOUT);
        InputStream inputStream = null;
        FileOutputStream fos = null;
        ByteArrayOutputStream bos = null;
        try {
            try {
                conn.setRequestProperty("user-agent", "datacloudsec scan upgrade");
                inputStream = conn.getInputStream();
                byte[] buffer = new byte[1024];
                bos = new ByteArrayOutputStream();
                while (true) {
                    int len = inputStream.read(buffer);
                    if (len == -1) {
                        break;
                    }
                    bos.write(buffer, 0, len);
                }
                byte[] getData = bos.toByteArray();
                File saveDir = new File(savePath);
                if (!saveDir.exists()) {
                    saveDir.mkdir();
                }
                File file = new File(saveDir + File.separator + ((fileName == null || "".equals(fileName)) ? urlStr.substring(urlStr.lastIndexOf("/") + 1, urlStr.length()) : fileName));
                fos = new FileOutputStream(file);
                fos.write(getData);
                IOUtils.closeQuietly(fos);
                IOUtils.closeQuietly(bos);
                IOUtils.closeQuietly(inputStream);
                return file;
            } catch (Exception e) {
                throw new UEException("文件下载失败", e);
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(fos);
            IOUtils.closeQuietly(bos);
            IOUtils.closeQuietly(inputStream);
            throw th;
        }
    }

    private Map<String, Object> invokePost(String ip, int port, String uri, boolean allowNoReponse, Map<String, Object> params, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到引擎地址");
        }
        String address = "https://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
        HttpURLConnection connection = (HttpURLConnection) new URL(address).openConnection();
        OutputStream outputStream = null;
        try {
            try {
                connection.setConnectTimeout(TIMEOUT);
                connection.setReadTimeout(TIMEOUT);
                connection.setDoOutput(true);
                connection.setDoInput(true);
                connection.setRequestMethod(post);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("Charset", "UTF-8");
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                String paramStr = (params == null || params.size() <= 0) ? "" : JsonUtil.MAPPER.writeValueAsString(params);
                connection.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", paramStr.getBytes("UTF-8"), ENGINE_PASSWORD));
                if (connection instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.2
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) connection).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) connection).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.3
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                try {
                    connection.connect();
                    outputStream = connection.getOutputStream();
                    outputStream.write(paramStr.getBytes("UTF8"));
                    return parseRepose(connection, requKey, allowNoReponse);
                } catch (Exception e) {
                    LOG.error("引擎连接失败：" + address, e);
                    throw new UEException("引擎连接失败", e);
                }
            } catch (Exception e2) {
                if (e2 instanceof UEException) {
                    throw e2;
                }
                throw new UEException("引擎执行失败", e2);
            }
        } finally {
            IOUtils.closeQuietly(outputStream);
            connection.disconnect();
        }
    }

    private Map<String, Object> invokeHttpPost(String ip, int port, String uri, boolean allowNoReponse, Map<String, Object> params, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到引擎地址");
        }
        String address = "http://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
        HttpURLConnection connection = (HttpURLConnection) new URL(address).openConnection();
        OutputStream outputStream = null;
        try {
            try {
                connection.setConnectTimeout(TIMEOUT);
                connection.setReadTimeout(TIMEOUT);
                connection.setDoOutput(true);
                connection.setDoInput(true);
                connection.setRequestMethod(post);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("Charset", "UTF-8");
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                String paramStr = (params == null || params.size() <= 0) ? "" : JsonUtil.MAPPER.writeValueAsString(params);
                connection.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", paramStr.getBytes("UTF-8"), ENGINE_PASSWORD));
                if (connection instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.4
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) connection).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) connection).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.5
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                try {
                    connection.connect();
                    outputStream = connection.getOutputStream();
                    outputStream.write(paramStr.getBytes("UTF8"));
                    return parseRepose(connection, requKey, allowNoReponse);
                } catch (Exception e) {
                    LOG.error("引擎连接失败：" + address, e);
                    throw new UEException("引擎连接失败", e);
                }
            } catch (Exception e2) {
                if (e2 instanceof UEException) {
                    throw e2;
                }
                throw new UEException("引擎执行失败", e2);
            }
        } finally {
            IOUtils.closeQuietly(outputStream);
            connection.disconnect();
        }
    }

    private Map<String, Object> invokePostFile(String ip, int port, String uri, boolean allowNoReponse, Map<String, Object> params, File f, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到调度引擎地址");
        }
        HttpURLConnection httpConn = null;
        DataOutputStream dos = null;
        try {
            try {
                String address = "https://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
                httpConn = (HttpURLConnection) new URL(address).openConnection();
                httpConn.setConnectTimeout(UPGRADE_TIMEOUT);
                httpConn.setReadTimeout(UPGRADE_TIMEOUT);
                httpConn.setDoInput(true);
                httpConn.setDoOutput(true);
                httpConn.setRequestMethod(post);
                httpConn.setUseCaches(false);
                httpConn.setRequestProperty("Connection", "Keep-Alive");
                httpConn.setRequestProperty("Accept", "*/*");
                httpConn.setRequestProperty("Accept-Encoding", "gzip, deflate");
                httpConn.setRequestProperty("Cache-Control", "no-cache");
                httpConn.setRequestProperty("Content-Type", "multipart/form-data; boundary=#");
                httpConn.setRequestProperty("User-Agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)");
                httpConn.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", FileUtils.readFileToByteArray(f), ENGINE_PASSWORD));
                if (httpConn instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.6
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) httpConn).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) httpConn).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.7
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                httpConn.connect();
                dos = new DataOutputStream(httpConn.getOutputStream());
                if (params != null && !params.isEmpty()) {
                    for (Map.Entry<String, Object> entry : params.entrySet()) {
                        String key = entry.getKey();
                        String value = new StringBuilder().append(params.get(key)).toString();
                        dos.writeBytes("--#\r\n");
                        dos.writeBytes("Content-Disposition: form-data; name=\"" + key + "\"\r\n");
                        dos.writeBytes("\r\n");
                        dos.writeBytes(URLEncoder.encode(value.toString(), "UTF-8"));
                        dos.writeBytes("\r\n");
                    }
                }
                byte[] body_data = FileUtils.readFileToByteArray(f);
                if (body_data != null && body_data.length > 0) {
                    dos.writeBytes("--#\r\n");
                    dos.writeBytes("Content-Disposition: form-data; name=\"bin\"; filename=\"" + f.getName() + "\"\r\n");
                    dos.writeBytes("\r\n");
                    dos.write(body_data);
                    dos.writeBytes("\r\n");
                }
                dos.writeBytes("--#--\r\n");
                dos.flush();
                Map<String, Object> parseRepose = parseRepose(httpConn, requKey, allowNoReponse);
                IOUtils.closeQuietly(dos);
                IOUtils.closeQuietly((InputStream) null);
                httpConn.disconnect();
                return parseRepose;
            } catch (Exception e) {
                if (e instanceof UEException) {
                    throw e;
                }
                throw new UEException("引擎执行失败", e);
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(dos);
            IOUtils.closeQuietly((InputStream) null);
            httpConn.disconnect();
            throw th;
        }
    }

    private Map<String, Object> invokeGet(String ip, int port, String uri, boolean allowNoReponse, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到调度引擎地址");
        }
        String address = "https://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
        HttpURLConnection connection = (HttpURLConnection) new URL(address).openConnection();
        try {
            try {
                connection.setConnectTimeout(TIMEOUT);
                connection.setReadTimeout(TIMEOUT);
                connection.setDoInput(true);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                connection.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", uri.getBytes("UTF-8"), ENGINE_PASSWORD));
                if (connection instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.8
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) connection).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) connection).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.9
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                try {
                    connection.connect();
                    return parseRepose(connection, requKey, allowNoReponse);
                } catch (Exception e) {
                    throw new UEException("引擎连接失败", e);
                }
            } catch (Exception e2) {
                if (e2 instanceof UEException) {
                    throw e2;
                }
                throw new UEException("引擎执行失败", e2);
            }
        } finally {
            IOUtils.closeQuietly((OutputStream) null);
            connection.disconnect();
        }
    }

    private Map<String, Object> invokeHttpGet(String ip, int port, String uri, boolean allowNoReponse, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到调度引擎地址");
        }
        String address = "http://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
        HttpURLConnection connection = (HttpURLConnection) new URL(address).openConnection();
        try {
            try {
                connection.setConnectTimeout(TIMEOUT);
                connection.setReadTimeout(TIMEOUT);
                connection.setDoInput(true);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                connection.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", uri.getBytes("UTF-8"), ENGINE_PASSWORD));
                if (connection instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.10
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) connection).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) connection).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.11
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                try {
                    connection.connect();
                    return parseRepose(connection, requKey, allowNoReponse);
                } catch (Exception e) {
                    LOG.error("引擎连接失败：" + address, e);
                    throw new UEException("引擎连接失败", e);
                }
            } catch (Exception e2) {
                if (e2 instanceof UEException) {
                    throw e2;
                }
                throw new UEException("引擎执行失败", e2);
            }
        } finally {
            IOUtils.closeQuietly((OutputStream) null);
            connection.disconnect();
        }
    }

    private Map<String, Object> invokeDelete(String ip, int port, String uri, boolean allowNoReponse, String... requKey) throws Exception {
        if (StringUtils.isBlank(ip) || port == 0) {
            throw new UEException("未获取到调度引擎地址");
        }
        String address = "https://" + (ip.contains(":") ? "[" + ip + "]" : ip) + ":" + port + uri;
        HttpURLConnection connection = (HttpURLConnection) new URL(address).openConnection();
        try {
            try {
                connection.setRequestMethod("DELETE");
                connection.setConnectTimeout(TIMEOUT);
                connection.setReadTimeout(TIMEOUT);
                connection.setDoInput(true);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                connection.setRequestProperty(SIGN_KEY, SecretUtil.encryptHMAC("HmacSha256", uri.getBytes("UTF-8"), ENGINE_PASSWORD));
                if (connection instanceof HttpsURLConnection) {
                    SSLContext sc = SSLContext.getInstance("SSL");
                    sc.init(null, new TrustManager[]{new X509TrustManager() { // from class: com.datacloudsec.scan.service.impl.EngineService.12
                        @Override // javax.net.ssl.X509TrustManager
                        public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                        }

                        @Override // javax.net.ssl.X509TrustManager
                        public X509Certificate[] getAcceptedIssuers() {
                            return new X509Certificate[0];
                        }
                    }}, new SecureRandom());
                    ((HttpsURLConnection) connection).setSSLSocketFactory(sc.getSocketFactory());
                    ((HttpsURLConnection) connection).setHostnameVerifier(new HostnameVerifier() { // from class: com.datacloudsec.scan.service.impl.EngineService.13
                        @Override // javax.net.ssl.HostnameVerifier
                        public boolean verify(String arg0, SSLSession arg1) {
                            return true;
                        }
                    });
                }
                try {
                    connection.connect();
                    return parseRepose(connection, requKey, allowNoReponse);
                } catch (Exception e) {
                    LOG.error("引擎连接失败：" + address, e);
                    throw new UEException("引擎连接失败", e);
                }
            } catch (Exception e2) {
                if (e2 instanceof UEException) {
                    throw e2;
                }
                throw new UEException("引擎执行失败", e2);
            }
        } finally {
            IOUtils.closeQuietly((OutputStream) null);
            connection.disconnect();
        }
    }

    public Map<String, Object> getUpgradeVersion(String url) throws Exception {
        if (url.indexOf("http://") == -1 && url.indexOf("https://") == -1) {
            url = "http://" + url;
        }
        HttpURLConnection connection = null;
        try {
            try {
                connection = (HttpURLConnection) new URL(url).openConnection();
                connection.setConnectTimeout(1000);
                connection.setReadTimeout(1000);
                connection.setDoInput(true);
                connection.setInstanceFollowRedirects(true);
                connection.setUseCaches(false);
                connection.setRequestProperty("accept", "*/*");
                connection.setRequestProperty("connection", "Keep-Alive");
                connection.setRequestProperty("user-agent", "datacloudsec scan upgrade");
                try {
                    connection.connect();
                    try {
                        int responseCode = connection.getResponseCode();
                        if (responseCode != 200) {
                            LOG.error("响应错误代码：" + responseCode);
                            throw new UEException("访问失败");
                        }
                        try {
                            byte[] contentBs = IOUtils.toByteArray(connection.getInputStream());
                            return (Map) JsonUtil.MAPPER.readValue(new String(contentBs, "UTF8"), new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.EngineService.14
                            });
                        } catch (Exception e) {
                            throw new UEException("读取引擎结果出错", e);
                        }
                    } catch (ConnectException e2) {
                        throw new UEException("连接被断开", e2);
                    } catch (Exception e3) {
                        throw new UEException("响应超时", e3);
                    }
                } catch (Exception e4) {
                    LOG.error("获取文件版本失败：" + url, e4);
                    throw new UEException("获取文件版本超时，请联系服务厂商！", e4);
                }
            } catch (Exception e5) {
                throw e5;
            }
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

    private static Map<String, Object> parseRepose(HttpURLConnection connection, String[] requKey, boolean allowNoReponse) throws Exception {
        try {
            int responseCode = connection.getResponseCode();
            if (responseCode != 200) {
                LOG.error("引擎响应错误代码：" + responseCode);
                throw new UEException("引擎访问失败");
            }
            try {
                byte[] contentBs = IOUtils.toByteArray(connection.getInputStream());
                String content = null;
                try {
                    content = new String(contentBs, "UTF8");
                    LOG.debug("响应" + content);
                    Map<String, Object> result = (Map) JsonUtil.MAPPER.readValue(content, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.EngineService.15
                    });
                    if (!"Success".equalsIgnoreCase(ObjectUtil.getString(result.get("state"), "Failed"))) {
                        String error = ObjectUtil.getString(result.get("error"), "");
                        throw new UEException(!"".equals(error) ? error : "引擎执行出错");
                    }
                    if (requKey != null) {
                        for (String key : requKey) {
                            if (result.get(key) == null) {
                                LOG.error("KEY：" + key + " 不能为空");
                                throw new UEException("引擎响应格式错误");
                            }
                        }
                    }
                    return result;
                } catch (Exception e) {
                    throw new UEException("解析引擎结果出错：" + content, e);
                }
            } catch (Exception e2) {
                throw new UEException("读取引擎结果出错", e2);
            }
        } catch (ConnectException e3) {
            if (allowNoReponse) {
                return null;
            }
            throw new UEException("引擎连接被断开", e3);
        } catch (Exception e4) {
            throw new UEException("引擎响应超时", e4);
        }
    }

    public Map<String, Object> getHostById(int localEid) throws Exception {
        Map<String, Object> engineInfo = hostMapper.getHostById(Integer.valueOf(localEid));
        if (engineInfo == null) {
            throw new UEException("未找到对应的引擎");
        }
        return engineInfo;
    }

    public String getPversion() throws Exception {
        return engMapper.getPversion();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void authvirusScan(final Integer deviceid, AbsDb db) throws Exception {
        Map<String, Object> json = new HashMap<>();
        json.put("taskID", "");
        json.put("dbType", db.getDbname());
        json.put("dbName", db.getDbname());
        json.put("ip", db.getIp());
        json.put("port", Integer.valueOf(db.getPort()));
        json.put("name", db.getUsername());
        json.put("password", db.getPassword());
        json.put("columnsType", new String[]{"text", "varchar"});
        com.datacloudsec.engine.db.virus.Engine engine = new com.datacloudsec.engine.db.virus.Engine(JsonUtil.MAPPER.writeValueAsString(json));
        engine.scan(db, new IVirusHandler() { // from class: com.datacloudsec.scan.service.impl.EngineService.16
            public void error(DbHandler db2, String arg1, Exception e, boolean arg3) {
            }

            public void finish(DbHandler db2) {
            }

            public void progress(DbHandler db2, int arg1) {
                Map<String, Object> dev = new HashMap<>();
                dev.put("devid", deviceid);
                dev.put("progress", Integer.valueOf(arg1));
                EngineService.taskBaseMapper.updateTaskDevice(dev);
            }

            public void result(DbHandler db2, String dbname, String tbname, String clumnname, long num, String info) {
                try {
                    EngineService.engMapper.dbAddVirus(deviceid, dbname, tbname, clumnname, num, info);
                } catch (Exception e) {
                    EngineService.LOG.error("", e);
                }
            }

            public void start(DbHandler arg0) {
                try {
                    EngineService.engMapper.dbDelVirus(deviceid);
                } catch (Exception e) {
                    EngineService.LOG.error("", e);
                }
            }
        });
    }

    /* JADX WARN: Type inference failed for: r0v29, types: [com.datacloudsec.scan.service.impl.EngineService$17] */
    private void authDbScan(final int deviceId, String ip, Map<String, String> taskOption) throws Exception {
        String username = taskOption.get("username");
        String password = taskOption.get("password");
        int port = ObjectUtil.getInt(taskOption.get("port"), 3306);
        String type = ObjectUtil.getString(taskOption.get("db"), (String) null);
        String dbname = taskOption.get("dbname");
        final String scanDest = taskOption.get("scanDest");
        int connectType = ObjectUtil.getInt(taskOption.get("connect_type"), 1);
        int role = ObjectUtil.getInt(taskOption.get("role"), 0);
        boolean useSsl = ObjectUtil.getBoolean(taskOption.get("useSsl"));
        final AbsDb db = AbsDb.createDb(type, ip, port, username, password, dbname, connectType, role, useSsl);
        new Thread() { // from class: com.datacloudsec.scan.service.impl.EngineService.17
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    com.datacloudsec.engine.db.auth.Engine dbEngine = new com.datacloudsec.engine.db.auth.Engine(new File[]{new File(Constant.CONF_DIR, "dbengine"), new File(Constant.CONF_DIR, "customDb/dbengine2")});
                    dbEngine.scan(db, new DbBugHandler(scanDest, db, EngineService.engMapper.getDeviceInfo(Integer.valueOf(deviceId))));
                } catch (Exception e) {
                    EngineService.LOG.error("", e);
                }
            }
        }.start();
    }

    /* JADX WARN: Type inference failed for: r0v14, types: [com.datacloudsec.scan.service.impl.EngineService$18] */
    private void nosqlDbScan(final int deviceId, String ip, Map<String, String> taskOption) throws Exception {
        String username = ObjectUtil.getString(taskOption.get("username"), "");
        String password = taskOption.get("password");
        int port = ObjectUtil.getInt(taskOption.get("port"), 6379);
        String type = ObjectUtil.getString(taskOption.get("db"), (String) null);
        final AbsNoSqlDb db = AbsNoSqlDb.createDb(type, ip, port, username, password);
        new Thread() { // from class: com.datacloudsec.scan.service.impl.EngineService.18
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    com.datacloudsec.engine.db.nosql.Engine nosqlEngine = new com.datacloudsec.engine.db.nosql.Engine(new File[]{new File(Constant.CONF_DIR, "dbengine_noauth"), new File(Constant.CONF_DIR, "customDb/dbengine_noauth2")});
                    nosqlEngine.scan(db, new NosqlBugHandler(EngineService.engMapper.getDeviceInfo(Integer.valueOf(deviceId))));
                } catch (Exception e) {
                    EngineService.LOG.error("", e);
                }
            }
        }.start();
    }

    /* JADX WARN: Type inference failed for: r0v7, types: [com.datacloudsec.scan.service.impl.EngineService$19] */
    private void noauthDbScan(final int deviceId, final String ip, Map<String, String> taskOption) throws Exception {
        final String db = taskOption.get("db");
        final int port = ObjectUtil.getInt(taskOption.get("port"), 3306);
        new Thread() { // from class: com.datacloudsec.scan.service.impl.EngineService.19
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    NoAuthDb db2 = new NoAuthDb(db, ip, port);
                    NoAuthEngine noAuthEngine = new NoAuthEngine(new File(Constant.WORK_DIR, "conf/dbengine_noauth"));
                    noAuthEngine.scan(db2, new DbNoauthBugHandler(EngineService.engMapper.getDeviceInfo(Integer.valueOf(deviceId))));
                } catch (Exception e) {
                    EngineService.LOG.error("", e);
                }
            }
        }.start();
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/EngineService$DbBlineHandler.class */
    private static class DbBlineHandler implements IHandler {
        private int id;
        private int scanCount;
        private Map<String, Object> device;
        private String topic = EngineService.configMapper.getValueByName("kafka_topic");
        private String address = EngineService.configMapper.getValueByName("kafka_address");

        public DbBlineHandler(int id, int scanCount) {
            this.id = id;
            this.scanCount = scanCount;
            this.device = EngineService.taskBaseMapper.getTaskDevById(Integer.valueOf(id));
        }

        public void error(com.datacloudsec.bline.engine.db.connect.AbsDb db, String errorText, Exception e, String ruleId, boolean isEnd) {
            if (errorText == null && e != null) {
                errorText = e.getMessage();
            }
            if (isEnd) {
                try {
                    EngineService.LOG.error("", e);
                    EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 3, (Double) null, (Integer) null, (Integer) null, errorText, (Integer) null, (Integer) null, (Integer) null, (Date) null, false);
                } catch (Exception e1) {
                    EngineService.LOG.error("", e1);
                    return;
                }
            }
            if (ruleId != null) {
                Task task = EngineService.taskBaseMapper.getTaskBydevId(Integer.valueOf(this.id));
                EngineService.engMapper.blineReplaceVul(Integer.valueOf(this.id), task == null ? "默认" : task.getBtype(), ruleId, 0, errorText);
            }
        }

        public void finish(com.datacloudsec.bline.engine.db.connect.AbsDb arg0) {
            try {
                Integer count = Integer.valueOf(EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 2, Double.valueOf(100.0d), (Integer) null, (Integer) null, (String) null, (Integer) null, (Integer) null, (Integer) null, new Date(), false));
                if (count == null || count.intValue() <= 0) {
                    EngineService.engMapper.delDbBlineByDevid(Integer.valueOf(this.id));
                    return;
                }
                if (this.scanCount > 0) {
                    List<Map<String, Object>> oldBugs = EngineService.blineBugMapper.getBlineResByDevid(Integer.valueOf(this.id));
                    EngineService.blineBugMapper.delResultByDevId(Integer.valueOf(this.id));
                    EngineService.engMapper.blineCopyRes(Integer.valueOf(this.id));
                    EngineService.blineBugMapper.delResultByDevId2(Integer.valueOf(this.id));
                    if (oldBugs != null && oldBugs.size() > 0) {
                        EngineService.blineBugMapper.addBlineResult2(oldBugs, Integer.valueOf(this.id));
                    }
                }
                Map<String, Object> bline = EngineService.blineBugMapper.bugCountByDev(Integer.valueOf(this.id));
                Date time = new Date();
                EngineService.blineBugMapper.addBlineStatis(1, Integer.valueOf(ObjectUtil.getInt(bline.get("hy"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("hn"), 0)), Integer.valueOf(this.id), time);
                EngineService.blineBugMapper.addBlineStatis(2, Integer.valueOf(ObjectUtil.getInt(bline.get("my"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("mn"), 0)), Integer.valueOf(this.id), time);
                EngineService.blineBugMapper.addBlineStatis(3, Integer.valueOf(ObjectUtil.getInt(bline.get("ly"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("ln"), 0)), Integer.valueOf(this.id), time);
                List<Map<String, Object>> queryBlineBug = EngineService.alarmlogMapper.queryBlineBug(Integer.valueOf(this.id));
                if (CollectionUtils.isNotEmpty(queryBlineBug)) {
                    EngineService.alarmlogMapper.delAlarmlogByTime();
                    EngineService.alarmlogMapper.batchInsert(queryBlineBug);
                }
                Map<String, Object> device = EngineService.taskBaseMapper.getTaskDevById(Integer.valueOf(this.id));
                Task task = EngineService.taskBaseMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                if (StringUtils.isNotBlank(task.getVal3()) && ReportService.REPORT_STATE_SUCCESS.equals(task.getVal3())) {
                    String expname = String.valueOf(task.getName()) + "_" + ObjectUtil.getString(device.get("name"), "").replace(".", "-").replaceAll("[\\s\\\\/:\\*\\?\\\"<>\\|]", "");
                    EngineService.reportService.export(ObjectUtil.getString(device.get("id"), ""), expname, "doc", (String) IReport.REPORT_CHK.get("bline"), "bline", (String) null, (String) null, (String) null, (String) null, (String) null, (String) null);
                }
                FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("bline"), "bline");
                SysLogJob.addBugs(EngineService.blineBugMapper.getBugsForLog(Integer.valueOf(this.id)));
                Map<String, Object> devinfo = EngineService.engMapper.getDeviceInfo(Integer.valueOf(this.id));
                if (ObjectUtil.getInt(devinfo.get("alarmType"), 0) == 1) {
                    AlermJob.alermDevice(devinfo);
                }
                if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                    try {
                        Map<String, Object> data = new HashMap<>();
                        data.put("ip", ObjectUtil.getString(device.get("ip"), ""));
                        KafkaUtil.getInstance().send(data);
                    } catch (Exception e) {
                        EngineService.LOG.error("kafka发送失败：", e);
                    }
                }
            } catch (Exception e2) {
                EngineService.LOG.error("", e2);
            }
        }

        public void result(com.datacloudsec.bline.engine.db.connect.AbsDb db, Policie.Policy policy, boolean isAccord, Object result, String customMod, String customDest) {
            String resultStr = null;
            if (result != null) {
                try {
                    if (result instanceof String) {
                        resultStr = (String) result;
                    } else if (result instanceof List) {
                        if (((List) result).size() > 0) {
                            resultStr = JsonUtil.MAPPER.writeValueAsString(result);
                        }
                    } else {
                        resultStr = JsonUtil.MAPPER.writeValueAsString(result);
                    }
                    resultStr = (resultStr == null || resultStr.length() > 5000) ? null : resultStr;
                } catch (Exception e) {
                    EngineService.LOG.error("策略ID：" + policy.getId(), e);
                    return;
                }
            }
            Task task = EngineService.taskBaseMapper.getTaskBydevId(Integer.valueOf(this.id));
            if (this.scanCount > 0) {
                EngineService.engMapper.blineReplaceVul2(Integer.valueOf(this.id), task == null ? "默认" : task.getBtype(), policy.getId(), Integer.valueOf(isAccord ? 0 : 1), resultStr);
            } else {
                EngineService.engMapper.blineReplaceVul(Integer.valueOf(this.id), task == null ? "默认" : task.getBtype(), policy.getId(), Integer.valueOf(isAccord ? 0 : 1), resultStr);
            }
            if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                try {
                    Map<String, Object> policyMap = EngineService.blineevalMapper.getBlineById(policy.getId(), "1=1", task == null ? "默认" : task.getBtype());
                    Map<String, Object> data = new HashMap<>();
                    data.put("bug_id", ObjectUtil.getString(policyMap.get("poliid"), ""));
                    data.put("bug_name", ObjectUtil.getString(policyMap.get("name"), ""));
                    data.put("bug_desct", ObjectUtil.getString(policyMap.get("desct"), ""));
                    data.put("bug_ip", ObjectUtil.getString(this.device.get("ip"), ""));
                    data.put("bug_type", ObjectUtil.getString(policyMap.get("name_cn"), ""));
                    data.put("bug_level", ObjectUtil.getString(policyMap.get("level"), ""));
                    data.put("bug_status", 1);
                    KafkaUtil.getInstance().send(data);
                } catch (Exception e2) {
                    EngineService.LOG.error("kafka发送失败：", e2);
                }
            }
        }

        public void start(com.datacloudsec.bline.engine.db.connect.AbsDb arg0, List<Policie.Policy> arg1) {
        }
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/EngineService$DbBugHandler.class */
    private static class DbBugHandler implements com.datacloudsec.engine.db.handler.IHandler {
        private Map<String, Object> device;
        private AbsDb dbType;
        private String scanDest;
        private int id;
        private String topic;
        private String address;

        public DbBugHandler(String scanDest, AbsDb db, Map<String, Object> device) {
            this.dbType = db;
            this.device = device;
            this.scanDest = scanDest;
            if (device != null) {
                this.id = ObjectUtil.getInt(device.get("id")).intValue();
            }
            this.topic = EngineService.configMapper.getValueByName("kafka_topic");
            this.address = EngineService.configMapper.getValueByName("kafka_address");
        }

        public void error(DbHandler db, String errorText, Exception e, String ruleId, boolean isEnd) {
            if (errorText == null && e != null) {
                errorText = e.getMessage();
            }
            if (isEnd) {
                try {
                    if (this.scanDest != null && this.scanDest.contains("virus")) {
                        EngineService.authvirusScan(Integer.valueOf(this.id), this.dbType);
                    }
                    EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 3, (Double) null, (Integer) null, (Integer) null, errorText, (Integer) null, (Integer) null, (Integer) null, (Date) null, false);
                    EngineService.LOG.error("", e);
                } catch (Exception e1) {
                    EngineService.LOG.error("", e1);
                }
            }
        }

        public void finish(DbHandler db) {
            try {
                if (this.scanDest != null && this.scanDest.contains("virus")) {
                    EngineService.authvirusScan(Integer.valueOf(this.id), this.dbType);
                }
                Integer count = Integer.valueOf(EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 2, Double.valueOf(100.0d), (Integer) null, (Integer) null, (String) null, (Integer) null, (Integer) null, (Integer) null, new Date(), false));
                if (count == null || count.intValue() <= 0) {
                    EngineService.engMapper.delDbResByDevId(Integer.valueOf(this.id));
                    return;
                }
                if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                    List<Map<String, Object>> oldBugs = EngineService.dbBugMapper.getDbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delBbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.dbCopyResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delDbResult2(Integer.valueOf(this.id));
                    if (oldBugs != null && oldBugs.size() > 0) {
                        EngineService.dbBugMapper.addDbResult2(oldBugs, Integer.valueOf(this.id));
                    }
                }
                Map<String, Object> bline = EngineService.dbBugMapper.bugCountByDev(Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(1, Integer.valueOf(ObjectUtil.getInt(bline.get("jj"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(2, Integer.valueOf(ObjectUtil.getInt(bline.get("gw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(3, Integer.valueOf(ObjectUtil.getInt(bline.get("zw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(4, Integer.valueOf(ObjectUtil.getInt(bline.get("dw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(5, Integer.valueOf(ObjectUtil.getInt(bline.get("xx"), 0)), Integer.valueOf(this.id));
                List<Map<String, Object>> queryDbBug = EngineService.alarmlogMapper.queryDbBug(Integer.valueOf(this.id));
                if (CollectionUtils.isNotEmpty(queryDbBug)) {
                    EngineService.alarmlogMapper.delAlarmlogByTime();
                    EngineService.alarmlogMapper.batchInsert(queryDbBug);
                }
                Map<String, Object> device2 = EngineService.taskBaseMapper.getTaskDevById(Integer.valueOf(this.id));
                Task task = EngineService.taskBaseMapper.getTaskById(ObjectUtil.getInt(device2.get("taskId")));
                FtpUtil.reportUpload(task, device2, (String) IReport.REPORT_CHK.get("db"), "db");
                SysLogJob.addBugs(EngineService.dbBugMapper.getBugsForLog(Integer.valueOf(this.id)));
                if (ObjectUtil.getInt(this.device.get("alarmType"), 0) == 1) {
                    AlermJob.alermDevice(this.device);
                }
                if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                    try {
                        Map<String, Object> data = new HashMap<>();
                        data.put("ip", ObjectUtil.getString(this.device.get("ip"), ""));
                        KafkaUtil.getInstance().send(data);
                    } catch (Exception e) {
                        EngineService.LOG.error("kafka发送失败：", e);
                    }
                }
            } catch (Exception e2) {
                EngineService.LOG.error("", e2);
            }
        }

        public void result(DbHandler db, String ruleId, int type, List<Map<String, Object>> info) {
            if (type != 0) {
                String infoResult = null;
                if (info != null) {
                    try {
                        if (info.size() > 0) {
                            if (info.size() == 1) {
                                Map<String, Object> m = info.get(0);
                                if (m.size() == 2 && m.containsKey("variable_name") && m.containsKey("variable_value")) {
                                    Map<String, Object> newMap = new HashMap<>();
                                    newMap.put((String) m.get("variable_name"), m.get("variable_value"));
                                    info.clear();
                                    info.add(newMap);
                                }
                            }
                            infoResult = JsonUtil.MAPPER.writeValueAsString(info);
                        }
                    } catch (Exception e) {
                        EngineService.LOG.error("策略ID：" + ruleId, e);
                        return;
                    }
                }
                if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                    EngineService.engMapper.dbAddResult2(Integer.valueOf(this.id), ruleId, infoResult);
                } else {
                    EngineService.engMapper.dbAddResult(Integer.valueOf(this.id), ruleId, infoResult);
                }
                if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                    try {
                        Map<String, Object> b = EngineService.dbTempMapper.getPolilyByOid(ruleId);
                        Map<String, Object> data = new HashMap<>();
                        data.put("bug_id", ObjectUtil.getString(b.get("id"), ""));
                        data.put("bug_name", ObjectUtil.getString(b.get("name"), ""));
                        data.put("bug_desct", ObjectUtil.getString(b.get("desct"), ""));
                        data.put("bug_ip", ObjectUtil.getString(this.device.get("ip"), ""));
                        data.put("bug_type", ObjectUtil.getString(b.get("ruletype"), ""));
                        data.put("bug_level", ObjectUtil.getString(b.get("level"), ""));
                        data.put("bug_status", 1);
                        KafkaUtil.getInstance().send(data);
                    } catch (Exception e2) {
                        EngineService.LOG.error("kafka发送失败：", e2);
                    }
                }
            }
        }

        public void start(DbHandler db, List<Map<String, Object>> ruleList) {
        }
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/EngineService$NosqlBugHandler.class */
    private static class NosqlBugHandler implements com.datacloudsec.engine.db.handler.IHandler {
        private int id;
        private Map<String, Object> device;
        private String topic;
        private String address;

        public NosqlBugHandler(Map<String, Object> device) {
            this.device = device;
            if (device != null) {
                this.id = ObjectUtil.getInt(device.get("id")).intValue();
            }
            this.topic = EngineService.configMapper.getValueByName("kafka_topic");
            this.address = EngineService.configMapper.getValueByName("kafka_address");
        }

        public void error(DbHandler db, String errorText, Exception e, String ruleId, boolean isEnd) {
            if (StringUtils.isBlank(errorText) && e != null) {
                errorText = e.getMessage();
            }
            if (isEnd) {
                try {
                    EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 3, (Double) null, (Integer) null, (Integer) null, errorText, (Integer) null, (Integer) null, (Integer) null, (Date) null, false);
                    EngineService.LOG.error("", e);
                } catch (Exception e1) {
                    EngineService.LOG.error("", e1);
                }
            }
        }

        public void finish(DbHandler db) {
            try {
                Integer count = Integer.valueOf(EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 2, Double.valueOf(100.0d), (Integer) null, (Integer) null, (String) null, (Integer) null, (Integer) null, (Integer) null, new Date(), false));
                if (count == null || count.intValue() <= 0) {
                    EngineService.engMapper.delDbResByDevId(Integer.valueOf(this.id));
                    return;
                }
                if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                    List<Map<String, Object>> oldBugs = EngineService.dbBugMapper.getDbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delBbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.dbCopyResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delDbResult2(Integer.valueOf(this.id));
                    if (oldBugs != null && oldBugs.size() > 0) {
                        EngineService.dbBugMapper.addDbResult2(oldBugs, Integer.valueOf(this.id));
                    }
                }
                Map<String, Object> bline = EngineService.dbBugMapper.bugCountByDev(Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(1, Integer.valueOf(ObjectUtil.getInt(bline.get("jj"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(2, Integer.valueOf(ObjectUtil.getInt(bline.get("gw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(3, Integer.valueOf(ObjectUtil.getInt(bline.get("zw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(4, Integer.valueOf(ObjectUtil.getInt(bline.get("dw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(5, Integer.valueOf(ObjectUtil.getInt(bline.get("xx"), 0)), Integer.valueOf(this.id));
                List<Map<String, Object>> queryDbBug = EngineService.alarmlogMapper.queryDbBug(Integer.valueOf(this.id));
                if (CollectionUtils.isNotEmpty(queryDbBug)) {
                    EngineService.alarmlogMapper.delAlarmlogByTime();
                    EngineService.alarmlogMapper.batchInsert(queryDbBug);
                }
                Map<String, Object> device2 = EngineService.taskBaseMapper.getTaskDevById(Integer.valueOf(this.id));
                Task task = EngineService.taskBaseMapper.getTaskById(ObjectUtil.getInt(device2.get("taskId")));
                FtpUtil.reportUpload(task, device2, (String) IReport.REPORT_CHK.get("db"), "db");
                SysLogJob.addBugs(EngineService.dbBugMapper.getBugsForLog(Integer.valueOf(this.id)));
                if (ObjectUtil.getInt(this.device.get("alarmType"), 0) == 1) {
                    AlermJob.alermDevice(this.device);
                }
                if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                    try {
                        Map<String, Object> data = new HashMap<>();
                        data.put("ip", ObjectUtil.getString(this.device.get("ip"), ""));
                        KafkaUtil.getInstance().send(data);
                    } catch (Exception e) {
                        EngineService.LOG.error("kafka发送失败：", e);
                    }
                }
            } catch (Exception e2) {
                EngineService.LOG.error("", e2);
            }
        }

        public void result(DbHandler db, String ruleId, int type, List<Map<String, Object>> info) {
            if (type != 0) {
                try {
                    if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                        EngineService.engMapper.dbAddResult2(Integer.valueOf(this.id), ruleId, JsonUtil.MAPPER.writeValueAsString(info));
                    } else {
                        EngineService.engMapper.dbAddResult(Integer.valueOf(this.id), ruleId, JsonUtil.MAPPER.writeValueAsString(info));
                    }
                    if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                        try {
                            Map<String, Object> b = EngineService.dbTempMapper.getPolilyByOid(ruleId);
                            Map<String, Object> data = new HashMap<>();
                            data.put("bug_id", ObjectUtil.getString(b.get("id"), ""));
                            data.put("bug_name", ObjectUtil.getString(b.get("name"), ""));
                            data.put("bug_desct", ObjectUtil.getString(b.get("desct"), ""));
                            data.put("bug_ip", ObjectUtil.getString(this.device.get("ip"), ""));
                            data.put("bug_type", ObjectUtil.getString(b.get("ruletype"), ""));
                            data.put("bug_level", ObjectUtil.getString(b.get("level"), ""));
                            data.put("bug_status", 1);
                            KafkaUtil.getInstance().send(data);
                        } catch (Exception e) {
                            EngineService.LOG.error("kafka发送失败：", e);
                        }
                    }
                } catch (Exception e2) {
                    EngineService.LOG.error("策略ID：" + ruleId, e2);
                }
            }
        }

        public void start(DbHandler db, List<Map<String, Object>> ruleList) {
        }
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/EngineService$DbNoauthBugHandler.class */
    private static class DbNoauthBugHandler implements com.datacloudsec.engine.db.handler.IHandler {
        private int id;
        private Map<String, Object> device;
        private String topic;
        private String address;

        public DbNoauthBugHandler(Map<String, Object> device) {
            this.device = device;
            if (device != null) {
                this.id = ObjectUtil.getInt(device.get("id")).intValue();
            }
            this.topic = EngineService.configMapper.getValueByName("kafka_topic");
            this.address = EngineService.configMapper.getValueByName("kafka_address");
        }

        public void error(DbHandler db, String errorText, Exception e, String ruleId, boolean isEnd) {
            if (StringUtils.isBlank(errorText) && e != null) {
                errorText = e.getMessage();
                if (errorText.contains("\"nmap\"")) {
                    errorText = "系统未发现nmap组件";
                }
            }
            if (isEnd) {
                try {
                    EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 3, (Double) null, (Integer) null, (Integer) null, errorText, (Integer) null, (Integer) null, (Integer) null, (Date) null, false);
                    EngineService.LOG.error("", e);
                } catch (Exception e1) {
                    EngineService.LOG.error("", e1);
                }
            }
        }

        public void finish(DbHandler db) {
            try {
                Integer count = Integer.valueOf(EngineService.engMapper.updateScanInfo(Integer.valueOf(this.id), 2, Double.valueOf(100.0d), (Integer) null, (Integer) null, (String) null, (Integer) null, (Integer) null, (Integer) null, new Date(), false));
                if (count == null || count.intValue() <= 0) {
                    EngineService.engMapper.delDbResByDevId(Integer.valueOf(this.id));
                    return;
                }
                if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                    List<Map<String, Object>> oldBugs = EngineService.dbBugMapper.getDbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delBbResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.dbCopyResult(Integer.valueOf(this.id));
                    EngineService.dbBugMapper.delDbResult2(Integer.valueOf(this.id));
                    if (oldBugs != null && oldBugs.size() > 0) {
                        EngineService.dbBugMapper.addDbResult2(oldBugs, Integer.valueOf(this.id));
                    }
                }
                Map<String, Object> bline = EngineService.dbBugMapper.bugCountByDev(Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(1, Integer.valueOf(ObjectUtil.getInt(bline.get("jj"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(2, Integer.valueOf(ObjectUtil.getInt(bline.get("gw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(3, Integer.valueOf(ObjectUtil.getInt(bline.get("zw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(4, Integer.valueOf(ObjectUtil.getInt(bline.get("dw"), 0)), Integer.valueOf(this.id));
                EngineService.dbBugMapper.addDbStatis(5, Integer.valueOf(ObjectUtil.getInt(bline.get("xx"), 0)), Integer.valueOf(this.id));
                List<Map<String, Object>> queryDbBug = EngineService.alarmlogMapper.queryDbBug(Integer.valueOf(this.id));
                if (CollectionUtils.isNotEmpty(queryDbBug)) {
                    EngineService.alarmlogMapper.delAlarmlogByTime();
                    EngineService.alarmlogMapper.batchInsert(queryDbBug);
                }
                Map<String, Object> device2 = EngineService.taskBaseMapper.getTaskDevById(Integer.valueOf(this.id));
                Task task = EngineService.taskBaseMapper.getTaskById(ObjectUtil.getInt(device2.get("taskId")));
                FtpUtil.reportUpload(task, device2, (String) IReport.REPORT_CHK.get("db"), "db");
                SysLogJob.addBugs(EngineService.dbBugMapper.getBugsForLog(Integer.valueOf(this.id)));
                if (ObjectUtil.getInt(this.device.get("alarmType"), 0) == 1) {
                    AlermJob.alermDevice(this.device);
                }
                if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                    try {
                        Map<String, Object> data = new HashMap<>();
                        data.put("ip", ObjectUtil.getString(this.device.get("ip"), ""));
                        KafkaUtil.getInstance().send(data);
                    } catch (Exception e) {
                        EngineService.LOG.error("kafka发送失败：", e);
                    }
                }
            } catch (Exception e2) {
                EngineService.LOG.error("", e2);
            }
        }

        public void result(DbHandler db, String ruleId, int type, List<Map<String, Object>> info) {
            if (type != 0) {
                try {
                    if (ObjectUtil.getInt(this.device.get("scanCount"), 0) != 1) {
                        EngineService.engMapper.dbAddResult2(Integer.valueOf(this.id), ruleId, JsonUtil.MAPPER.writeValueAsString(info));
                    } else {
                        EngineService.engMapper.dbAddResult(Integer.valueOf(this.id), ruleId, JsonUtil.MAPPER.writeValueAsString(info));
                    }
                    if (StringUtils.isNotBlank(this.topic) && StringUtils.isNotBlank(this.address)) {
                        try {
                            Map<String, Object> b = EngineService.dbTempMapper.getPolilyByOid(ruleId);
                            Map<String, Object> data = new HashMap<>();
                            data.put("bug_id", ObjectUtil.getString(b.get("id"), ""));
                            data.put("bug_name", ObjectUtil.getString(b.get("name"), ""));
                            data.put("bug_desct", ObjectUtil.getString(b.get("desct"), ""));
                            data.put("bug_ip", ObjectUtil.getString(this.device.get("ip"), ""));
                            data.put("bug_type", ObjectUtil.getString(b.get("ruletype"), ""));
                            data.put("bug_level", ObjectUtil.getString(b.get("level"), ""));
                            data.put("bug_status", 1);
                            KafkaUtil.getInstance().send(data);
                        } catch (Exception e) {
                            EngineService.LOG.error("kafka发送失败：", e);
                        }
                    }
                } catch (Exception e2) {
                    EngineService.LOG.error("策略ID：" + ruleId, e2);
                }
            }
        }

        public void start(DbHandler db, List<Map<String, Object>> ruleList) {
        }
    }

    public static void main(String[] args) throws Exception {
    }
}
